Enable all nova v3 tests
To merge a nova v3 patch (I452672e064d0dc4a1d5700bb96c01de8087f33d8),
all nova v3 tests have been skipped because the patch changes common
parameter("admin_password") of nova v3 API.
After merging the patch, we need to enable all nova v3 tests again with
changing the API parameter.
Partially implements blueprint nova-v3-api-tests
Change-Id: Ia5b3bd123a20196fd15bbb6771b6cf929121532a
diff --git a/etc/tempest.conf.sample b/etc/tempest.conf.sample
index fc4f9cd..4d02dc5 100644
--- a/etc/tempest.conf.sample
+++ b/etc/tempest.conf.sample
@@ -153,7 +153,7 @@
[compute-feature-enabled]
# Do we run the Nova V3 API tests?
-api_v3 = false
+api_v3 = true
# Does the Compute API support creation of images?
create_image = true
diff --git a/tempest/api/compute/base.py b/tempest/api/compute/base.py
index d9ede31..f29a202 100644
--- a/tempest/api/compute/base.py
+++ b/tempest/api/compute/base.py
@@ -260,7 +260,7 @@
pass
resp, server = cls.create_test_server(wait_until='ACTIVE', **kwargs)
cls.server_id = server['id']
- cls.password = server['admin_pass']
+ cls.password = server['admin_password']
class BaseV3ComputeAdminTest(BaseV3ComputeTest):
diff --git a/tempest/api/compute/v3/servers/test_server_actions.py b/tempest/api/compute/v3/servers/test_server_actions.py
index fb4214a..8ac1f12 100644
--- a/tempest/api/compute/v3/servers/test_server_actions.py
+++ b/tempest/api/compute/v3/servers/test_server_actions.py
@@ -122,7 +122,7 @@
name=new_name,
metadata=meta,
personality=personality,
- admin_pass=password)
+ admin_password=password)
# Verify the properties in the initial response are correct
self.assertEqual(self.server_id, rebuilt_server['id'])
diff --git a/tempest/config.py b/tempest/config.py
index 76461fb..a629486 100644
--- a/tempest/config.py
+++ b/tempest/config.py
@@ -204,7 +204,7 @@
ComputeFeaturesGroup = [
cfg.BoolOpt('api_v3',
- default=False,
+ default=True,
help="If false, skip all nova v3 tests."),
cfg.BoolOpt('disk_config',
default=True,
diff --git a/tempest/services/compute/v3/xml/servers_client.py b/tempest/services/compute/v3/xml/servers_client.py
index 6f38b6a..7a8b370 100644
--- a/tempest/services/compute/v3/xml/servers_client.py
+++ b/tempest/services/compute/v3/xml/servers_client.py
@@ -295,7 +295,7 @@
flavor_ref=flavor_ref,
image_ref=image_ref,
name=name)
- attrs = ["admin_pass", "access_ip_v4", "access_ip_v6", "key_name",
+ attrs = ["admin_password", "access_ip_v4", "access_ip_v6", "key_name",
("os-user-data:user_data",
'user_data',
'xmlns:os-user-data',
@@ -438,7 +438,7 @@
def change_password(self, server_id, password):
return self.action(server_id, "change_password", None,
- admin_pass=password)
+ admin_password=password)
def reboot(self, server_id, reboot_type):
return self.action(server_id, "reboot", None, type=reboot_type)
@@ -586,9 +586,10 @@
return self.action(server_id, 'get_console_output', 'output',
length=length)
- def rescue_server(self, server_id, admin_pass=None):
+ def rescue_server(self, server_id, admin_password=None):
"""Rescue the provided server."""
- return self.action(server_id, 'rescue', None, admin_pass=admin_pass)
+ return self.action(server_id, 'rescue', None,
+ admin_password=admin_password)
def unrescue_server(self, server_id):
"""Unrescue the provided server."""
diff --git a/tempest/services/compute/v3/json/servers_client.py b/tempest/services/compute/v3/json/servers_client.py
index a005edb..21b2b40 100644
--- a/tempest/services/compute/v3/json/servers_client.py
+++ b/tempest/services/compute/v3/json/servers_client.py
@@ -42,7 +42,7 @@
image_ref (Required): Reference to the image used to build the server.
flavor_ref (Required): The flavor used to build the server.
Following optional keyword arguments are accepted:
admin_pass: Sets the initial root password.
key_name: Key name of keypair that was created earlier.
meta: A dictionary of values to be used as metadata.
personality: A list of dictionaries for files to be injected into
@@ -64,7 +64,7 @@
'flavor_ref': flavor_ref
}
- for option in ['personality', 'admin_pass', 'key_name',
+ for option in ['personality', 'admin_password', 'key_name',
'security_groups', 'networks',
('os-user-data:user_data', 'user_data'),
('os-availability-zone:availability_zone',
@@ -367,9 +367,10 @@
return self.action(server_id, 'get_console_output', 'output',
length=length)
- def rescue_server(self, server_id, adminPass=None):
+ def rescue_server(self, server_id, admin_password=None):
"""Rescue the provided server."""
- return self.action(server_id, 'rescue', None, admin_pass=adminPass)
+ return self.action(server_id, 'rescue', None,
+ admin_password=admin_password)
def unrescue_server(self, server_id):
"""Unrescue the provided server."""
@@ -42,7 +42,7 @@
flavor_ref (Required): The flavor used to build the server.
Following optional keyword arguments are accepted:
- admin_pass: Sets the initial root password.
+ admin_password: Sets the initial root password.
key_name: Key name of keypair that was created earlier.
meta: A dictionary of values to be used as metadata.